pub fn from_str<'de, T>(
flavor: Flavor,
input: &'de str,
) -> Result<T, Located<'de, Error>>where
T: Deserialize<'de>,Expand description
Deserialize a value from a string.
This is a convenience function to deserialize a value with some sensible defaults. In particular, this uses a fixed recursion depth of 64. If you are getting a MaxRecursion error, please use Deserializer directly.
This function will return UnescapeBufferFull if the input contains escaped strings or escaped bytes. Use from_str_escaped instead, or opt-out of unescaping with Escaped.
For deserializing from bytes, see from_slice.